import {
  Emitter
} from "../../chunk-RRIVLGL4.js";
import {
  useDispose
} from "../../chunk-AKDX6FMT.js";
import "../../chunk-TSCDX4AS.js";
import "../../chunk-PAMCEPLQ.js";
import "../../chunk-D6B6MYVG.js";
import "../../chunk-EO6XKBST.js";
import "../../chunk-RDQTC3AH.js";
import "../../chunk-QCZA4HNR.js";
import "../../chunk-XGHGEMIC.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-ZFRTRIT4.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-UHTVWILC.js";
import "../../chunk-T7PU5CTZ.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-KQSQJAHU.js";
import "../../chunk-X2DIUKLP.js";
import "../../chunk-2HWPZ6ZE.js";
import {
  objectInclusivePick,
  objectMap,
  objectMergeDisposable,
  objectOmit,
  objectPick,
  objectPlain
} from "../../chunk-XOOIUMF2.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-M6LJR6SZ.js";
import {
  isNotNull
} from "../../chunk-NXVGWT4R.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-O4U55KGC.js";
import "../../chunk-4XPO57AQ.js";
import "../../chunk-MVRB7Y7X.js";
import "../../chunk-FSDCRQB3.js";
import "../../chunk-MRFHKDNG.js";
import "../../chunk-AEBHR4XF.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-NS4INNCL.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-R6KULE2F.js";
import "../../chunk-7NSVDPHN.js";
import "../../chunk-VVNSHVPQ.js";
import "../../chunk-6GHO7LQW.js";

// src/common/data/object.spec.ts
describe("object.spec", () => {
  it("should map it", async () => {
    const sample = {
      a: 1,
      b: 2
    };
    expect(objectMap(sample, (k, v) => v + 10)).toMatchInlineSnapshot(`
      Object {
        "a": 11,
        "b": 12,
      }
    `);
    expect(objectMap(sample, (k, v) => [`${k}_${v}`, k])).toMatchInlineSnapshot(`
        Object {
          "a_1": "a",
          "b_2": "b",
        }
      `);
  });
  it("should merge", async () => {
    const emitter = new Emitter();
    const obj = {
      dispose: useDispose(),
      f() {
        return 42;
      }
    };
    let x = 1;
    obj.dispose.add(() => x++);
    const m = objectMergeDisposable(emitter, obj);
    expect(m.f()).toBe(42);
    m.on("a", () => x++);
    void m.emit("a");
    expect(x).toBe(2);
    await m.dispose();
    expect(x).toBe(3);
  });
  it("should omit and pick", () => {
    const o = { a: 1, b: 2, c: 3, d: 4 };
    expect(objectPick(o, "a", "c")).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "c": 3,
      }
    `);
    expect(objectOmit(o, "a", "c")).toMatchInlineSnapshot(`
      Object {
        "b": 2,
        "d": 4,
      }
    `);
    expect(objectInclusivePick(o, "a", "c", "x")).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "c": 3,
        "x": undefined,
      }
    `);
  });
});
describe("objectPlain", () => {
  it("should return the plain object", () => {
    const obj = {
      a: 1,
      b: {
        c: 2,
        d: [3, 4]
      }
    };
    const result = objectPlain(obj);
    expect(result).toEqual(obj);
  });
  it("should handle circular references", () => {
    const obj = {
      a: 1
    };
    obj.b = obj;
    const result = objectPlain(obj, { circleValue: "*** CIRCULAR ***" });
    expect(result).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "b": "*** CIRCULAR ***",
      }
    `);
  });
  it("should handle nested objects", () => {
    const obj = {
      a: 1,
      b: {
        c: 2,
        d: {
          e: 3
        }
      }
    };
    const result = objectPlain(obj);
    expect(result).toEqual(obj);
  });
  it("should handle arrays", () => {
    const obj = {
      a: 1,
      b: [2, 3, 4]
    };
    const result = objectPlain(obj);
    expect(result).toEqual(obj);
  });
  it("should handle max depth", () => {
    const obj = {
      a: {
        b: {
          c: {
            d: {
              e: 1
            }
          }
        }
      }
    };
    const result = objectPlain(obj, { maxDepth: 3, maxDepthValue: "*** MAX DEPTH ***" });
    expect(result).toEqual({
      a: {
        b: {
          c: {
            d: "*** MAX DEPTH ***"
          }
        }
      }
    });
  });
  it("should handle removeUndefined", () => {
    const obj = {
      a: 1,
      b: void 0,
      c: [1, void 0]
    };
    const result = objectPlain(obj, { filter: isNotNull });
    expect(result).toEqual({ a: 1, c: [1] });
  });
  it("should also support crazy stuff", () => {
    function fn() {
      this.y = 1;
    }
    fn.prototype.x = 2;
    fn.z = 6;
    class Klass {
      constructor() {
        this.name = "test";
      }
    }
    const obj = {
      a: 1,
      b: {
        x: Symbol("x"),
        y: BigInt(123),
        fn,
        nan: Number.NaN,
        inf: Number.POSITIVE_INFINITY,
        err: new Error("err"),
        set: /* @__PURE__ */ new Set([1, { x: 1 }, 3]),
        rx: /.*?.test/gim,
        map: /* @__PURE__ */ new Map([
          ["a", 1],
          ["b", 2],
          [true, "bool"]
        ]),
        weakMap: /* @__PURE__ */ new WeakMap(),
        uint8: new Uint8Array([1, 2, 3]),
        uint16: new Uint16Array([1, 2, 3]),
        c: 2,
        d: [3, 4, 5],
        Klass,
        newKlass: new Klass()
      }
    };
    const result = objectPlain(obj, {
      keepAsIs: (o) => o instanceof Uint8Array,
      errorTrace: false
    });
    expect(result).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "b": Object {
          "Klass": Object {},
          "c": 2,
          "d": Array [
            3,
            4,
            5,
          ],
          "err": "Error: err",
          "fn": Object {
            "z": 6,
          },
          "inf": Infinity,
          "map": Object {
            "a": 1,
            "b": 2,
            "true": "bool",
          },
          "nan": NaN,
          "newKlass": Object {
            "name": "test",
          },
          "rx": "/.*?.test/gim",
          "set": Array [
            1,
            Object {
              "x": 1,
            },
            3,
          ],
          "uint16": Array [
            1,
            2,
            3,
          ],
          "uint8": Uint8Array [
            1,
            2,
            3,
          ],
          "weakMap": Object {},
          "x": "Symbol(x)",
          "y": 123n,
        },
      }
    `);
  });
});
//# sourceMappingURL=object.spec.js.map