"use strict";

var _chunkBS7LZTVNcjs = require('../../chunk-BS7LZTVN.cjs');
require('../../chunk-H5CRRFPC.cjs');
require('../../chunk-MKPXOLNJ.cjs');
require('../../chunk-4B2XCWGL.cjs');
require('../../chunk-RQERABKF.cjs');
require('../../chunk-5CIFX7O6.cjs');
require('../../chunk-TVMYMQ3E.cjs');
require('../../chunk-EX6RJ3WB.cjs');
require('../../chunk-G3RAF7HY.cjs');
require('../../chunk-BBX7CCGY.cjs');
require('../../chunk-DCCSUOSM.cjs');
require('../../chunk-J42M6DF3.cjs');
require('../../chunk-N46W55MH.cjs');
require('../../chunk-UKD65B23.cjs');
require('../../chunk-L646RZQB.cjs');
require('../../chunk-ZYPCVNSG.cjs');
require('../../chunk-CXBBK7CI.cjs');
require('../../chunk-R7WMTFSS.cjs');
require('../../chunk-DRTH56G4.cjs');
require('../../chunk-XWE2OTGL.cjs');
require('../../chunk-KTC5RW57.cjs');
require('../../chunk-A4VFMLAN.cjs');
require('../../chunk-GU6AYGWK.cjs');
require('../../chunk-RKOTNV3K.cjs');
require('../../chunk-ZGKV237Z.cjs');
require('../../chunk-7WFR6WZW.cjs');
require('../../chunk-N7OUNPMM.cjs');
require('../../chunk-MPD2DJAD.cjs');
require('../../chunk-YELWQAMG.cjs');
require('../../chunk-USVMO7UT.cjs');
require('../../chunk-TNS27NHR.cjs');
require('../../chunk-FEYF6QXS.cjs');
require('../../chunk-HMHMDCOK.cjs');
require('../../chunk-3SM3C7HY.cjs');
require('../../chunk-EE5CB3R7.cjs');


var _chunkQYCE2TUJcjs = require('../../chunk-QYCE2TUJ.cjs');
require('../../chunk-5KIDARFB.cjs');
require('../../chunk-CEXYDYSH.cjs');
require('../../chunk-PJXRDQ2A.cjs');
require('../../chunk-6T6PI6XG.cjs');
require('../../chunk-XDY4SRCL.cjs');
require('../../chunk-FYLSPYV2.cjs');
require('../../chunk-YKRFYR2Q.cjs');
require('../../chunk-QU2LM4AI.cjs');
require('../../chunk-BMRI2X66.cjs');
require('../../chunk-66YRDFQP.cjs');
require('../../chunk-7FPSHSSO.cjs');

// src/common/exec/queue.spec.ts
describe("queue", () => {
  it("should execute in strict order", async () => {
    expect.assertions(1);
    const list = [];
    const queue = new (0, _chunkBS7LZTVNcjs.SerialQueue)();
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 1);
      list.push("c");
    });
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
  });
  it("should execute in random order", async () => {
    expect.assertions(1);
    const list = [];
    void (async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 100);
      list.push("a");
    })();
    void (async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 200);
      list.push("b");
    })();
    void (async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 1);
      list.push("c");
    })();
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 500);
    expect(list).toEqual(["c", "a", "b"]);
  });
  it("should return value", async () => {
    expect.assertions(2);
    const list = [];
    const queue = new (0, _chunkBS7LZTVNcjs.SerialQueue)();
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 100);
      list.push("a");
    });
    const r = await queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 200);
      list.push("b");
      return 123;
    });
    expect(r).toEqual(123);
    expect(list).toEqual(["a", "b"]);
    await queue.wait();
  });
  it("should pause", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new (0, _chunkBS7LZTVNcjs.SerialQueue)();
    const events = [];
    queue.onAny((...args) => events.push(args));
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 1);
      list.push("c");
    });
    await queue.pause();
    expect(list).toEqual(["a"]);
    queue.resume();
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didStart",
          1,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didUpdate",
          3,
          1,
        ],
        Array [
          "didUpdate",
          3,
          2,
        ],
        Array [
          "didUpdate",
          3,
          3,
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
  it("should cancel the rest", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new (0, _chunkBS7LZTVNcjs.SerialQueue)();
    const events = [];
    queue.onAny((...args) => events.push(args));
    await queue.pause();
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 1);
      list.push("c");
    }).then((r) => {
      expect(r).toBe(void 0);
    });
    await queue.cancelAll();
    queue.resume();
    await queue.wait();
    expect(list).toEqual([]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didCancel",
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
});
//# sourceMappingURL=queue.spec.cjs.map